==> photo_editor_sdk-0.4.8.tar.gz: ios/Classes/LogoStickerToolController.swift <==
//
//  LogoStickerToolController.swift
//  Runner
//
//  Created by Danilo Pena on 15/05/20.
//  Copyright © 2020 The Chromium Authors. All rights reserved.
//

import UIKit
import PhotoEditorSDK

@available(iOS 9.0, *)
open class LogoStickerToolController: StickerToolController {
    private let podBundle = Bundle(for: SwiftPhotoEditorSdkPlugin.self) // for getting pod url
    private var buttonAddLogo = UIButton()
    
    open override func viewDidLoad() {
        super.viewDidLoad()
        
        menuViewController.hideMenu(animated: true)
        stickerSelectionController.collectionView.contentInset = UIEdgeInsets(top: 0, left: 0, bottom: 60, right: 0)

        stickerSelectionController.stickerPreviewSize = CGSize(width: (UIScreen.main.bounds.width / 2) - 40, height: 100)
        attLogos()

        //Add when add logo was finished
        /*
        let uiView = UIView()
        uiView.backgroundColor = .white
        uiView.translatesAutoresizingMaskIntoConstraints = false
        view.addSubview(uiView)
        
        uiView.bottomAnchor.constraint(equalTo: view.bottomAnchor, constant: 0).isActive = true
        uiView.rightAnchor.constraint(equalTo: view.rightAnchor, constant: 0).isActive = true
        uiView.leftAnchor.constraint(equalTo: view.leftAnchor, constant: 0).isActive = true
        uiView.heightAnchor.constraint(equalToConstant: 60).isActive = true
        
        buttonAddLogo.setImage(UIImage(named: "ico_add_logo", in: self.podBundle, compatibleWith: nil), for: .normal)
        buttonAddLogo.translatesAutoresizingMaskIntoConstraints = false
        buttonAddLogo.addTarget(self, action: #selector(addLogo), for: .touchUpInside)
        
        uiView.addSubview(buttonAddLogo)
        
        buttonAddLogo.centerYAnchor.constraint(equalTo: uiView.centerYAnchor, constant: 0).isActive = true
        buttonAddLogo.leftAnchor.constraint(equalTo: uiView.leftAnchor, constant: 14).isActive = true
        buttonAddLogo.heightAnchor.constraint(equalToConstant: 40).isActive = true
        buttonAddLogo.widthAnchor.constraint(equalToConstant: 140).isActive = true
        */
    }
    
    private func addLoading() {
        buttonAddLogo.alpha = 0.5
        buttonAddLogo.isUserInteractionEnabled = false
    }
    
    private func removeLoading() {
        buttonAddLogo.alpha = 1.0
        buttonAddLogo.isUserInteractionEnabled = true
    }
    
    private func attLogos() {
        stickerSelectionController.stickers = createStickerSection(key: "logos", index: 1)
        stickerSelectionController.collectionView.reloadData()
    }
    
    @objc private func addLogo() {
        ImagePickerManager().pickImage(self){ image in
            let uploadManager = UploadImageManager()
            uploadManager.imageData = image.pngData()
            if let request = uploadManager.makeRequest() {
                self.addLoading()
                URLSession.shared.dataTask(with: request) { data, response, error in
                    if let dataNotnull = data {
                        if let httpResponse = response as? HTTPURLResponse {
                            self.removeLoading()
                            if httpResponse.statusCode == 200 {
                                do {
                                    let result = try JSONDecoder().decode(AddedLogoResponse.self, from: dataNotnull)
                                    print(result.new_logo_url ?? "bugou")
                                    UserDefaults.standard.set(result.logo_list, forKey: "logos")
                                    DispatchQueue.main.async {
                                        self.attLogos()
                                    }
                                } catch {
                                    print(error)
                                }
                            } else {
                                let str = String(decoding: dataNotnull, as: UTF8.self)
                            }
                        }
                    }
                }.resume()
            }
        }
    }
    
    private func createStickerSection(key: String, index: Int) -> [Sticker] {
        var images: [Sticker] = []
        let defaults = UserDefaults.standard
        let logos = defaults.array(forKey: key)
        var cont = 0
        logos?.forEach { logo in
            if let logoURL = URL(string: logo as! String) {
                let logoSticker = Sticker(imageURL: logoURL, thumbnailURL: nil, identifier: "\(cont) \(index)")
                cont = cont+1
                images.append(logoSticker)
            }
        }
        return images
    }
}

==> photo_editor_sdk-0.4.10.tar.gz: ios/Classes/LogoStickerToolController.swift <==
//
//  LogoStickerToolController.swift
//  Runner
//
//  Created by Danilo Pena on 15/05/20.
//  Copyright © 2020 The Chromium Authors. All rights reserved.
//

import UIKit
import PhotoEditorSDK

class AddLogoSingleton: NSObject {
    private override init() {}
    static var instance = AddLogoSingleton()
    @objc dynamic var addLogo = false
}

@available(iOS 9.0, *)
open class LogoStickerToolController: StickerToolController {
    private let podBundle = Bundle(for: SwiftPhotoEditorSdkPlugin.self) // for getting pod url
    private var buttonAddLogo = UIButton()

    open override func viewDidLoad() {
        super.viewDidLoad()
        menuViewController.hideMenu(animated: true)
        stickerSelectionController.collectionView.contentInset = UIEdgeInsets(top: 0, left: 0, bottom: 60, right: 0)

        stickerSelectionController.stickerPreviewSize = CGSize(width: (UIScreen.main.bounds.width / 2) - 40, height: 100)
        attLogos()

        //Add when add logo was finished
        
        let uiView = UIView()
        uiView.backgroundColor = .white
        uiView.translatesAutoresizingMaskIntoConstraints = false
        view.addSubview(uiView)
        
        uiView.bottomAnchor.constraint(equalTo: view.bottomAnchor, constant: 0).isActive = true
        uiView.rightAnchor.constraint(equalTo: view.rightAnchor, constant: 0).isActive = true
        uiView.leftAnchor.constraint(equalTo: view.leftAnchor, constant: 0).isActive = true
        uiView.heightAnchor.constraint(equalToConstant: 60).isActive = true
        
        buttonAddLogo.setImage(UIImage(named: "ico_add_logo", in: self.podBundle, compatibleWith: nil), for: .normal)
        buttonAddLogo.translatesAutoresizingMaskIntoConstraints = false
        buttonAddLogo.addTarget(self, action: #selector(addLogo), for: .touchUpInside)
        
        uiView.addSubview(buttonAddLogo)
        
        buttonAddLogo.centerYAnchor.constraint(equalTo: uiView.centerYAnchor, constant: 0).isActive = true
        buttonAddLogo.leftAnchor.constraint(equalTo: uiView.leftAnchor, constant: 14).isActive = true
        buttonAddLogo.heightAnchor.constraint(equalToConstant: 40).isActive = true
        buttonAddLogo.widthAnchor.constraint(equalToConstant: 140).isActive = true
        
    }
    
    private func addLoading() {
        buttonAddLogo.alpha = 0.5
        buttonAddLogo.isUserInteractionEnabled = false
    }
    
    private func removeLoading() {
        buttonAddLogo.alpha = 1.0
        buttonAddLogo.isUserInteractionEnabled = true
    }
    
    private func attLogos() {
        stickerSelectionController.stickers = createStickerSection(key: "logos", index: 1)
        stickerSelectionController.collectionView.reloadData()
    }
    
    @objc private func addLogo() {
        AddLogoSingleton.instance.addLogo = true
//        ImagePickerManager().pickImage(self){ image in
//            let uploadManager = UploadImageManager()
//            uploadManager.imageData = image.pngData()
//            if let request = uploadManager.makeRequest() {
//                self.addLoading()
//                URLSession.shared.dataTask(with: request) { data, response, error in
//                    if let dataNotnull = data {
//                        if let httpResponse = response as? HTTPURLResponse {
//                            self.removeLoading()
//                            if httpResponse.statusCode == 200 {
//                                do {
//                                    let result = try JSONDecoder().decode(AddedLogoResponse.self, from: dataNotnull)
//                                    print(result.new_logo_url ?? "bugou")
//                                    UserDefaults.standard.set(result.logo_list, forKey: "logos")
//                                    DispatchQueue.main.async {
//                                        self.attLogos()
//                                    }
//                                } catch {
//                                    print(error)
//                                }
//                            } else {
//                                let str = String(decoding: dataNotnull, as: UTF8.self)
//                            }
//                        }
//                    }
//                }.resume()
//            }
//        }
    }
    
    private func createStickerSection(key: String, index: Int) -> [Sticker] {
        var images: [Sticker] = []
        let defaults = UserDefaults.standard
        let logos = defaults.array(forKey: key)
        var cont = 0
        logos?.forEach { logo in
            if let logoURL = URL(string: logo as! String) {
                let logoSticker = Sticker(imageURL: logoURL, thumbnailURL: nil, identifier: "\(cont) \(index)")
                cont = cont+1
                images.append(logoSticker)
            }
        }
        return images
    }
}
